#bin/sh
Current_DIR=$(cd `dirname $0`; pwd)
startTime=`date +%s`
valuesFile=$Current_DIR/values.yaml

die() {
  echo "ERROR: $1"
  exit 2
}

warning() {
  echo -e "\e[33;1;33mWARNING: $1\e[33;0m"
}

getValueFromValues(){
  fileName=$2
  [[ -z $fileName ]] && fileName=$valuesFile
  index=$(sed -n '/'"$1":'/=' $fileName)
  if [ -z $index ];then
    echo ""
    return $?
  fi
  lineStr=$(cat $fileName | awk 'NR=='"$index"'')
  echo ${lineStr: $(expr length $1)+2}
  return $?
}

replaceFileContent() {
  if [[ `echo $operatorSystem | grep -ciw "Darwin"` = 1 ]]
  then
    # Mac
    sed -i '' $@
  else
    # Linux
    sed -i "$@"
  fi
}

# compareTo 1 1 --> 0
# compareTo 1 2 --> -1
# compareTo 1 0 --> 1
compareTo() {
  echo `awk -v n1=$1 -v n2=$2 'BEGIN{print (n1-n2) == 0 ? "0" : ((n1-n2)>0 ? "1":"-1")}'`
}

checkRequiredService() {
  builtinDisabledValue=$1;
  externalServiceValue=$2;
  serviceName=$3;
  builtinDisabled=$(getValueFromValues $builtinDisabledValue);
  externalService=$(getValueFromValues $externalServiceValue);
  if [[ $builtinDisabled == "true" && -z $externalService ]]; then
      die "The required value for $serviceName service is missing. If the $builtinDisabledValue value is true, the variable of $serviceName service is required";
  fi
}

# deploy_kubernetes_public_ip
[[ -z "$(getValueFromValues deploy_kubernetes_public_ip)" ]] && die "Please set deploy_kubernetes_public_ip in values.yaml"

# deploy_domain_ip
if [ -z $(getValueFromValues deploy_domain_ip) ]; then
  kubernetes_first_node_ip=$(kubectl get nodes -o wide --no-headers | awk '{print $6}' | head -1)
  replaceFileContent 's|deploy_domain_ip:.*|'"deploy_domain_ip: $kubernetes_first_node_ip"'|g' $valuesFile
fi

# deploy_storage_class_name
storage_class_name=$(getValueFromValues deploy_storage_class_name)
nfs_server=$(getValueFromValues deploy_nfs_server)
if [[ -z $nfs_server && -n $storage_class_name ]]; then
  if [[ `kubectl get storageclass $storage_class_name --ignore-not-found=true --no-headers=true | grep -c .` != 1 ]]; then
      die "storage class $storage_class_name does not exist";
    fi
fi

# deploy_disable_bslicense_local_volume
[[ "$(getValueFromValues deploy_disable_bslicense_local_volume)" == "true" ]] && [[ -z "$nfs_server" ]] && [[ -z "$storage_class_name" ]] && die "bslicense mount use nfs but nfs server is empty"

#check required service
checkRequiredService "deploy_disable_ispeco_database" "deploy_ispeco_database_host" "ispeco-mysql"
checkRequiredService "deploy_disable_keycloak" "deploy_keycloak_host" "keycloak"
[[ "$(getValueFromValues deploy_disable_keycloak)" != "true" ]] && checkRequiredService "deploy_disable_keycloak_postgresql" "deploy_keycloak_postgresql_host" "keycloak-postgresql"
checkRequiredService "deploy_disable_bslicense" "deploy_bslicense_server_host" "bslicense-server"
checkRequiredService "deploy_disable_consul_server" "deploy_consul_server_host" "consul-server"
checkRequiredService "deploy_disable_rabbitmq" "deploy_rabbitmq_host" "rabbitmq"
checkRequiredService "deploy_disable_redis" "deploy_redis_host" "redis"
if [[ "$(getValueFromValues deploy_disable_iportal)" != "true" ]]; then
  checkRequiredService "deploy_disable_iportal_database" "deploy_iportal_database_host" "iportal-mysql"
  checkRequiredService "deploy_disable_iportal_postgis" "deploy_iportal_postgis_host" "iportal-postgis"
  checkRequiredService "deploy_disable_iportal_memcached" "deploy_iportal_memcached_host" "iportal-memcached"
  checkRequiredService "deploy_disable_iportal_elasticsearch" "deploy_iportal_elasticsearch_host" "iportal-elasticsearch"
fi

# deploy_ispeco_user_name
deploy_ispeco_user_name=$(getValueFromValues deploy_ispeco_user_name)
while [[ -z $deploy_ispeco_user_name ]]
do
  echo -n "Please enter administrator user name: ";
  read deploy_ispeco_user_name
  replaceFileContent 's|deploy_ispeco_user_name:.*|deploy_ispeco_user_name: '"$deploy_ispeco_user_name"'|' $valuesFile
done

# deploy_memory_limit
deploy_memory_limit=$(getValueFromValues deploy_memory_limit)
if [[ `echo $deploy_memory_limit | grep -ic g` -gt 0 ]]; then
  index=`expr index $deploy_memory_limit g`
  [[ $index -eq 0 ]] && index=`expr index $deploy_memory_limit G`
  number=${deploy_memory_limit:0:`expr $index - 1`}
elif [[ `echo $deploy_memory_limit | grep -ic m` -gt 0 ]]; then
  index=`expr index $deploy_memory_limit m`
  [[ $index -eq 0 ]] && index=`expr index $deploy_memory_limit M`
  number=${deploy_memory_limit:0:`expr $index - 1`}
  number=`expr $number / 1024`
fi
if [[ `compareTo $number 4` -eq -1 ]]; then
  warning "The value of deploy_memory_limit is less than 4Gi, set deploy_memory_limit to 4Gi";
  deploy_memory_limit=4Gi
  replaceFileContent 's|deploy_memory_limit:.*|'"deploy_memory_limit: $deploy_memory_limit"'|g' $valuesFile
fi

# deploy_async_function_enabled: 
deploy_async_function_enabled=$(getValueFromValues deploy_async_function_enabled)
if [[ -z $deploy_async_function_enabled ]]; then 
  if [[ -n $(kubectl explain component 2>/dev/null) && -n $(kubectl explain scaledjobs 2>/dev/null) ]]; then
    deploy_async_function_enabled=true
  else
    deploy_async_function_enabled=false
  fi
  replaceFileContent 's|deploy_async_function_enabled:.*|'"deploy_async_function_enabled: $deploy_async_function_enabled"'|g' $valuesFile
elif [[ "$deploy_async_function_enabled" == "true" ]]; then
  if [[ -z $(kubectl explain component 2>/dev/null) || -z $(kubectl explain scaledjobs 2>/dev/null) ]]; then
    warning "The system is without a Dapr and KEDA environment, set deploy_async_function_enabled to false";
    deploy_async_function_enabled=false
    replaceFileContent 's|deploy_async_function_enabled:.*|'"deploy_async_function_enabled: $deploy_async_function_enabled"'|g' $valuesFile
  fi
fi

# deploy_sync_function_enabled: 
deploy_sync_function_enabled=$(getValueFromValues deploy_sync_function_enabled)
if [[ -z $deploy_sync_function_enabled ]]; then 
  if [[ -n $(kubectl explain ksvc 2>/dev/null) ]]; then
    deploy_sync_function_enabled=true
  else
    deploy_sync_function_enabled=false
  fi
  replaceFileContent 's|deploy_sync_function_enabled:.*|'"deploy_sync_function_enabled: $deploy_sync_function_enabled"'|g' $valuesFile
elif [[ "$deploy_sync_function_enabled" == "true" && -z $(kubectl explain ksvc 2>/dev/null) ]]; then
  warning "The system is without a Knative environment, set deploy_sync_function_enabled to false";
  deploy_sync_function_enabled=false
  replaceFileContent 's|deploy_sync_function_enabled:.*|'"deploy_sync_function_enabled: $deploy_sync_function_enabled"'|g' $valuesFile
fi

# deploy_namespace
ns=$(getValueFromValues deploy_namespace)
[[ -z "$ns" ]] && ns="giscloudsuite"
nsCount=`kubectl get ns --ignore-not-found=true | awk -F ' ' '{ print $1 }' | grep "^$ns$" -c`
if [[ $nsCount -gt 0 ]];then
  echo "namespace exist: $ns"
else
  kubectl create ns $ns
fi

# Install giscloudsuite
if [[ $($Current_DIR/helm list -n $ns | awk -F ' ' '{ print $1 }' | grep '^giscloudsuite$' -c) -gt 0 ]];then
  $Current_DIR/helm upgrade giscloudsuite $Current_DIR -n $ns
else
  $Current_DIR/helm install giscloudsuite $Current_DIR -n $ns
fi

function waitPods(){
 task=0
 while [ $task -lt 100 ]
 do
   total=`kubectl get pod -n $ns --no-headers=true --ignore-not-found | grep . -c`
   running=`kubectl get pod -n $ns --ignore-not-found | grep 'Running' -c`
   completed=`kubectl get pod -n $ns --ignore-not-found | grep 'Completed' -c`
   ok=$[ $running + $completed ]
   if [[ $total -gt 0 ]]; then
      task=$[ $ok * 100 / $total ]
   else
      task=1
   fi
   if [[ $task -gt 100 ]]; then
      task=100
   fi
   b='#'
   for n in $(seq 1 $task)
   do
      b='#'$b
   done;
   printf "progress:[%-100s](%d%%)\r" $b $task
   sleep 2s
 done
 echo ""
}
waitPods
endTime=`date +%s`
subTime=$[ $endTime - $startTime]
echo "Startup Completed in $subTime s"

if [[ -z "$nfs_server" && -z "$storage_class_name" ]];then
  chmod 777 -R /opt/giscloudsuite/
fi