{{- define "image.mariadb" -}}
  mariadb:10.5.19-arm64
{{- end -}}
{{- define "image.phpmyadmin" -}}
  phpmyadmin:5.2.1-arm64
{{- end -}}
{{- define "image.tiny-tools" -}}
  tiny-tools:1.0-arm64
{{- end -}}
{{- define "image.consul" -}}
  consul:1.5.1-arm64
{{- end -}}
{{- define "image.redis" -}}
  redis:5.0.9-arm64
{{- end -}}
{{- define "image.rabbitmq" -}}
  rabbitmq:3.9.20-management-arm64
{{- end -}}
{{- define "image.k8s-dashboard" -}}
  k8s-dashboard-imanager:v1.8.3-arm64
{{- end -}}
{{- define "image.metrics-server" -}}
  metrics-server:v0.4.5-arm64
{{- end -}}
{{- define "image.node-exporter" -}}
  node-exporter:v0.18.1-arm64
{{- end -}}
{{- define "image.kube-state-metrics" -}}
  kube-state-metrics:v2.2.4-arm64
{{- end -}}
{{- define "image.nginx-ingress-controller" -}}
  nginx-ingress-controller:v1.2.1-arm64
{{- end -}}
{{- define "image.prometheus" -}}
  prometheus:v2.41.0-arm64
{{- end -}}
{{- define "image.nfs-client-provisioner" -}}
  nfs-subdir-external-provisioner:v4.0.2-arm64
{{- end -}}
{{- define "image.postgres" -}}
  postgres:10-arm64
{{- end -}}
{{- define "image.postgis" -}}
  postgis-imanager:10-alpine-arm64
{{- end -}}
{{- define "image.elasticsearch" -}}
  elasticsearch-imanager:6.8.23-arm64
{{- end -}}
{{- define "image.keycloak-proxy" -}}
  keycloak-proxy:2.0-arm64
{{- end -}}
{{- define "image.memcached" -}}
  memcached:1.5.3-arm64
{{- end -}}
{{- define "image.postgresql.pgpool" -}}
  pgpool:4.2.2-debian-10-r4-arm64
{{- end -}}
{{- define "image.postgresql.repmgr" -}}
  postgresql-repmgr:11.11.0-debian-10-r5-arm64
{{- end -}}
{{- define "image.alpine-with-oracle-client" -}}
{{- end -}}
{{- define "image.alpine-with-fonts" -}}
  alpine-with-fonts:1.0-arm64
{{- end -}}
{{- define "image.blackbox-exporter" -}}
  blackbox-exporter-linux:v0.18.0-arm64
{{- end -}}
{{- define "image.blackbox-exporter-proxy" -}}
  blackbox-exporter-proxy:1.0-arm64
{{- end -}}
{{- define "elasticsearch_xpack_ml_enable" -}}
  false
{{- end -}}
{{- define "spark_worker_tag" -}}
  3.3.0-hadoop3.3-iobjects{{ include "deploy_image_tag" . }}
{{- end -}}
{{- define "metrics.node_memory_MemTotal" -}}
  node_memory_MemTotal_bytes
{{- end -}}
{{- define "metrics.node_memory_MemFree" -}}
  node_memory_MemFree_bytes
{{- end -}}
{{- define "metrics.node_memory_Cached" -}}
  node_memory_Cached_bytes
{{- end -}}
{{- define "metrics.node_memory_Buffers" -}}
  node_memory_Buffers_bytes
{{- end -}}
{{- define "metrics.node_filesystem_size" -}}
  node_filesystem_size_bytes
{{- end -}}
{{- define "metrics.node_filesystem_avail" -}}
  node_filesystem_avail_bytes
{{- end -}}
{{- define "metrics.node_network_receive_bytes" -}}
  node_network_receive_bytes_total
{{- end -}}
{{- define "metrics.node_network_transmit_bytes" -}}
  node_network_transmit_bytes_total
{{- end -}}
{{- define "keycloak_postgresql_addr" -}}
  keycloak-postgresql
{{- end -}}
{{- define "keycloak_postgresql_tpl" -}}
apiVersion: v1
kind: PersistentVolumeClaim
metadata:
  labels:
{{ include "icloud_native.labels" . | indent 4 }}
  name: pvc-keycloak-postgresql-data-{{ template "appset_id" . }}
spec:
  storageClassName: {{ template "storage_class_name" . }}
  accessModes:
    - ReadWriteMany
  resources:
    requests:
      storage: 8Gi
---
apiVersion: apps/v1
kind: Deployment
metadata:
  labels:
{{ include "icloud_native.labels" . | indent 4 }}
    app: keycloak-postgresql
    group: base-service
  name: keycloak-postgresql
  annotations:
    scale: unscalable
    description: icloud_native_keycloak_postgresql_description
    topoProperty: "{'name':'keycloak-postgresql','isPivot':'false','index':21,'parents':[]}"
spec:
  replicas: 1
  strategy: 
    type: Recreate
  selector:
    matchLabels:
      app: keycloak-postgresql
  template:
    metadata:
      labels:
        app: keycloak-postgresql
    spec:
{{ include "affinity" . | indent 6 }}
{{ include "tolerations" . | indent 6 }}
      imagePullSecrets:
      - name: "{{ template "deploy_image_pull_secret" . }}"
      containers:
      - env:
        - name: POSTGRES_DB
          value: keycloak
        - name: POSTGRES_PASSWORD
          valueFrom:
            secretKeyRef:
              name: icloud-native-secret
              key: keycloak.postgresql.password
        - name: POSTGRES_USER
          value: supermap
        image: {{ template "deploy_registry" . }}/{{ template "deploy_image_namespace" . }}/{{ template "image.postgres" }}
        name: keycloak-postgresql
        imagePullPolicy: {{ template "deploy_image_pull_policy" . }}
        ports:
        - containerPort: 5432
        livenessProbe:
          tcpSocket:
            port: 5432
          failureThreshold: 5
          initialDelaySeconds: 30
          periodSeconds: 10
          successThreshold: 1
          timeoutSeconds: 15
        readinessProbe:
          tcpSocket:
            port: 5432
          failureThreshold: 5
          initialDelaySeconds: 30
          periodSeconds: 10
          successThreshold: 1
          timeoutSeconds: 15
        startupProbe:
          tcpSocket:
            port: 5432
          failureThreshold: 20
          periodSeconds: 30
          timeoutSeconds: 20
        resources:
          limits:
            cpu: 2
            memory: 2Gi
          requests:
            cpu: 100m
            memory: 200Mi
        volumeMounts:
        - mountPath: /var/lib/postgresql/data
          name: postgresql-volume
        - mountPath: /etc/localtime
          name: timezone
        - mountPath: /etc/timezone
          name: timezone
      restartPolicy: Always
      volumes:
      - name: postgresql-volume
        persistentVolumeClaim: 
          claimName: pvc-keycloak-postgresql-data-{{ template "appset_id" . }}
      - name:  timezone
        hostPath:
          path: /etc/localtime
{{- end -}}